## Summary

<!-- Brief description of the changes -->

## Type of Change

- [ ] Bug fix
- [ ] New feature
- [ ] Breaking change
- [ ] Documentation update
- [ ] Refactoring

## Checklist

- [ ] Tests pass locally (`pytest`)
- [ ] Type checks pass (`mypy agenter`)
- [ ] Linting passes (`ruff check`)
- [ ] Documentation updated (if applicable)

## Related Issues

<!-- Link any related issues: Fixes #123, Closes #456 -->
